@@ -1,9 +1,9 @@
+from clickable.config.constants import Constants
 from clickable.config.project import ProjectConfig
 from clickable.commands.docker.docker_config import DockerConfig
 from clickable.utils import get_existing_dir
 from .docker_support import DockerSupport
 import os
-import getpass
 
 
 class MultimediaSupport(DockerSupport):
@@ -14,23 +14,26 @@ class MultimediaSupport(DockerSupport):
 
     def update(self, docker_config: DockerConfig):
         uid = os.getuid()
-        user = getpass.getuser()
 
         pulse_run_dir = get_existing_dir('Pulse run', [
             f'/run/user/{uid}/pulse',
             f'/run/{uid}/pulse',
-        ])
+        ], optional=True)
 
         pulse_conf_dir = get_existing_dir('Pulse configuration', [
-            f'/home/{user}/.pulse',
-            f'/home/{user}/.config/pulse',
-        ])
+            os.path.join(Constants.host_home, '.pulse'),
+            os.path.join(Constants.host_home, '.config/pulse'),
+        ], optional=True)
 
         docker_config.volumes.update({
             '/dev/shm': '/dev/shm',
             '/etc/machine-id': '/etc/machine-id',
-            pulse_run_dir: '/run/user/1000/pulse',
             '/var/lib/dbus': '/var/lib/dbus',
-            pulse_conf_dir: '/home/phablet/.pulse',
             '/dev/snd': '/dev/snd',
         })
+
+        if pulse_run_dir:
+            docker_config.volumes[pulse_run_dir] = '/run/user/1000/pulse'
+
+        if pulse_conf_dir:
+            docker_config.volumes[pulse_conf_dir] = os.path.join(Constants.device_home, '.pulse')
